@@ -200,17 +200,6 @@ abstract class CMapElement extends CApiService {
 				);
 			}
 
-			if ($selement['elementtype'] == SYSMAP_ELEMENT_TYPE_MAP) {
-				$label = array_key_exists('label', $selement) ? $selement['label'] : '';
-				foreach ($selement['elements'] as $element) {
-					if ($this->checkCircleSelementsLink($selement['sysmapid'], $element['sysmapid'])) {
-						self::exception(ZBX_API_ERROR_PARAMETERS,
-							_s('Circular link cannot be created for map element "%s".', $label)
-						);
-					}
-				}
-			}
-
 			if ($create) {
 				$selement['urls'] = array_key_exists('urls', $selement) ? $selement['urls'] : [];
 			}
@@ -359,27 +348,6 @@ abstract class CMapElement extends CApiService {
 		return true;
 	}
 
-	public function checkCircleSelementsLink($sysmapId, $elementId) {
-		if (bccomp($sysmapId, $elementId) == 0) {
-			return true;
-		}
-
-		$dbElements = DBselect(
-			'SELECT se.elementid,se.elementtype'.
-			' FROM sysmaps_elements se'.
-			' WHERE se.sysmapid='.zbx_dbstr($elementId).
-				' AND se.elementtype='.SYSMAP_ELEMENT_TYPE_MAP
-		);
-		while ($element = DBfetch($dbElements)) {
-			// get data from sysmap_element_trigger if type trigger
-			if ($this->checkCircleSelementsLink($sysmapId, $element['elementid'])) {
-				return true;
-			}
-		}
-
-		return false;
-	}
-
 	/**
 	 * Add element to sysmap.
 	 *
