@@ -693,17 +693,17 @@ elseif (hasRequest('add') || hasRequest('update')) {
 				if ($db_item['description'] !== getRequest('description', '')) {
 					$item['description'] = getRequest('description', '');
 				}
+				if ($db_item['preprocessing'] !== $preprocessing) {
+					$item['preprocessing'] = $preprocessing;
+				}
 			}
 
 			if ($db_item['status'] != getRequest('status', ITEM_STATUS_DISABLED)) {
 				$item['status'] = getRequest('status', ITEM_STATUS_DISABLED);
 			}
 
-			if ($db_item['preprocessing'] !== $preprocessing) {
-				$item['preprocessing'] = $preprocessing;
-			}
-
-			if (getRequest('type') == ITEM_TYPE_DEPENDENT) {
+			if (getRequest('type') == ITEM_TYPE_DEPENDENT && hasRequest('master_itemid')
+					&& bccomp($db_item['master_itemid'], getRequest('master_itemid')) != 0) {
 				$item['master_itemid'] = getRequest('master_itemid');
 			}
 
